#
# spec file for package rrdtool
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#



Name:           rrdtool
BuildRequires:  cairo-devel freetype2-devel glib2-devel intltool libart_lgpl-devel libpng-devel libxml2-devel pango-devel python-devel tcl-devel
%if 0%{?suse_version} >= 1100
BuildRequires:  gettext-tools
%else
BuildRequires:  gettext
%endif
BuildRequires:  ruby-devel
%if 0%{?suse_version} >= 920
%define has_lua 1
BuildRequires:  lua-devel
%endif
BuildRequires:  autoconf automake libtool
BuildRequires:  tcpd-devel
License:        GPLv2+
Group:          Productivity/Scientific/Math
Requires:       perl = %{perl_version}
Version:        1.4.5
Release:        4.5.1
%define cgilib_version 0.7
# http://oss.oetiker.ch/rrdtool/pub/rrdtool-%{version}.tar.gz
Source:         %{name}-%{version}.tar.bz2
Patch1:         rrdtool-lua_lib64.patch
Patch2:         rrdtool-tclversion.patch
Patch3:         rrdtool-tclsegfault.patch
# http://www.infodrom.org/projects/cgilib/download/cgilib-%{cgilib_version}.tar.gz
Source1:        cgilib-%{cgilib_version}.tar.bz2
Patch11:        cgilib-fix_automake.patch
Url:            http://oss.oetiker.ch/rrdtool/
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Summary:        A tool for data logging and analysis
Requires:       dejavu

%description
A tool to log and analyze data gathered from all kinds of data sources.
The data analysis part of RRDtool is based on the ability to quickly
generate graphical representations of the data values collected over a
definable time period.

%prep
%setup -q -a1
%if %{_lib}==lib64
%patch1
%endif
%patch2
%patch3
pushd "cgilib-%{cgilib_version}"
%patch11
popd #cgilib

%build
# first prepare cgilib
pushd cgilib-%{cgilib_version}
echo -n > NEWS
aclocal --force
autoreconf -fiv
CGILIB_CFLAGS="%{optflags} -fPIC -I."
%if 0%{?suse_version} >= 1130
CGILIB_CFLAGS="$CGILIB_CFLAGS -fexcess-precision=fast"
%endif
CFLAGS="$CGILIB_CFLAGS" \
%configure
make %{?jobs:-j %jobs}
%__mkdir_p ../lb/include
%__cp *.h ../lb/include/
%__mkdir_p ../lb/lib/
%__cp -a .libs/libcgi.so* ../lb/lib/
popd #cgilib

# build rrdtool
%{suse_update_config}
if [ ! -d m4 ]; then mkdir m4; fi
# we need getext 0.18
#autoreconf -i -f
%if %{_lib}==lib64
# don't pass -i to autoreconf, that'll run autopoint which will go
# nuts because of the supposedly outdated gettext version:
autoreconf -fv
%endif
export LDFLAGS="-L`pwd`/lb/lib" CPPFLAGS="-I`pwd`/lb/include" \
%configure --disable-static --with-pic --enable-shared \
            --with-tcllib=%{_libdir} \
            --with-gnu-ld \
            --disable-rpath \
            --with-rrd-default-font="monospace" 
make %{?jobs:-j %jobs} V=1

%install
#eval `perl -V:installarchlib`
make \
    DESTDIR=$RPM_BUILD_ROOT \
    idocdir=%{_docdir}/%{name}/txt/ \
    ihtmldir=%{_docdir}/%{name}/html/ \
    examplesdir=%{_docdir}/%{name}/examples/ \
    libdir=%{_libdir} \
    pkglibdir=%_datadir/tcl/tclrrd%version \
    TCL_PACKAGE_DIR=%_datadir/tcl/tclrrd%version \
    TCL_PACKAGE_PATH=%_datadir/tcl \
    install
# we install this later again
rm -r $RPM_BUILD_ROOT%{_prefix}/lib/perl
# do not install fonts (use system fonts instead)
rm -rf $RPM_BUILD_ROOT%_datadir/rrdtool/fonts
# install correctly perl modules
pushd bindings/perl-piped 
perl Makefile.PL
make DESTDIR=$RPM_BUILD_ROOT install_vendor
popd
pushd bindings/perl-shared 
perl Makefile.PL
make DESTDIR=$RPM_BUILD_ROOT install_vendor
popd
%perl_process_packlist
#fix build (it would be better to split cgilib)
#sed 's/[[:space:]]*-L\/usr\/src\/packages\/BUILD\/%{name}-%{version}\/lb\/lib[[:space:]]*/ /' $RPM_BUILD_ROOT/%{_libdir}/librrd.la > tmp
#mv tmp $RPM_BUILD_ROOT/%{_libdir}/librrd.la
#sed 's/[[:space:]]*-L\/usr\/src\/packages\/BUILD\/%{name}-%{version}\/lb\/lib[[:space:]]*/ /' $RPM_BUILD_ROOT/%{_libdir}/librrd_th.la > tmp
#mv tmp $RPM_BUILD_ROOT/%{_libdir}/librrd_th.la
find "%{buildroot}" -type f -name '*.la' -exec %__rm {} \;
# documentation
install -m 644 CHANGES CONTRIBUTORS COPYING COPYRIGHT README TODO $RPM_BUILD_ROOT/%{_docdir}/%{name}
# Script libraries for Tcl extensions should be in a package-specific
# subdir of /usr/share/tcl
mkdir -p $RPM_BUILD_ROOT/usr/share/tcl/tclrrd%{version}
#mv $RPM_BUILD_ROOT/usr/lib/tclrrd%{version}/pkgIndex.tcl \
#   $RPM_BUILD_ROOT/usr/share/tcl/tclrrd%{version}

%clean
rm -rf $RPM_BUILD_ROOT

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%defattr(-, root, root)
%doc %{_docdir}/rrdtool
%doc %{_mandir}/*/*
/usr/bin/*
%{_datadir}/tcl
%{_libdir}/librrd.so.*
%{_libdir}/librrd_th.so.*
%{_libdir}/tclrrd*.so
%{perl_vendorlib}/RRDp.pm
%{perl_vendorarch}/RRDs.pm
#%{perl_vendorarch}/ntmake.pl
%{perl_vendorarch}/auto/*
%if %suse_version < 1140
/var/adm/perl-modules/rrdtool
%endif
#%{_datadir}/%{name}

%package devel
License:        GPLv2+
Summary:        A tool for data logging and analysis - Development files
Group:          Productivity/Scientific/Math
Requires:       %name = %version

%description devel
A tool to log and analyze data gathered from all kinds of data sources.
The data analysis part of RRDtool is based on the ability to quickly
generate graphical representations of the data values collected over a
definable time period.


%files devel
%defattr(-, root, root)
/usr/include/*
%{_libdir}/librrd_th.so
%{_libdir}/librrd.so
%{_libdir}/pkgconfig/librrd.pc

%package -n python-rrdtool
License:        GPLv2+
Summary:        Python bindings for rrdtool
Group:          Productivity/Scientific/Math
Requires:       %name = %version
%py_requires

%description -n python-rrdtool
A tool to log and analyze data gathered from all kinds of data sources.
The data analysis part of RRDtool is based on the ability to quickly
generate graphical representations of the data values collected over a
definable time period.

This package contains the Python bindings

%files -n python-rrdtool
%defattr(-, root, root)
%{py_sitedir}/*

%if 0%{?has_lua}

%package -n lua-rrdtool
License:        GPLv2+
Summary:        Lua bindings for rrdtool
Group:          Productivity/Scientific/Math
Requires:       %name = %version

%description -n lua-rrdtool
A tool to log and analyze data gathered from all kinds of data sources.
The data analysis part of RRDtool is based on the ability to quickly
generate graphical representations of the data values collected over a
definable time period.

This package contains the Lua bindings

%files -n lua-rrdtool
%defattr(-, root, root)
%dir %{_libdir}/lua
%dir %{_libdir}/lua/*
%{_libdir}/lua/*/rrd.so
%{_libdir}/lua/*/rrd.so.*
%endif

%changelog
* Thu May 12 2011 max@novell.com
- Fix two segfaults in the Tcl binding.
* Wed May 11 2011 max@novell.com
- Fix a version dependency problem with Tcl (bnc#693085).
* Tue Dec 28 2010 pascal.bleser@opensuse.org
- build lua bindings (new subpackage lua-rrdtool)
- update to 1.4.5:
  * rrdcached: print \n at the end of log messages when running rrdcached in the foreground
  * rrdcached: Let the -s, -m and -P options affect the default socket as well
  * rrdgraph: font related memory leaks fixed #208
  * rrdgraph-libdbi: print error message instead of dumping core on sql problem
  * rrdgraph-libdbi: properly allocated response buffer
  * rrdtool: in remote mode, make argument count for remote commmands strict
  * rrdgraph: fix problems with second %%s in right-axis format
  * everywhere: fix locale handling. locales were not properly reset after calling set locale
  * rrdgraph: fix use of %%s in strftime (G)PRINT commands #277
  * ruby: fix bindings to be compatible with curent ruby implementations #279
  * rrdcached: Ensure that response_read() always calls fflush() or fclose() #278
  * rrd_client: free addrinfo list after use ...
  * rrdupdate: follow the normal code path for exiting rrd_update if there is a problem with rrdc, plugging a memory leak on the way
  * rrdgraph: make sure we do not try to draw points all that far outside the drawing area since some versions of cairo seem to go unstable when this happens
  * rrdgraph: fix an endles loop near 2^31 timestamp (32bit platform problem)
  * rrdcached: fix permissions of the default socket
  * rrdgraph-libdbi: Fix sigma calculation
  * rrdcreate: better checks for RRA arguments
  * rrdgraph: if there is no right label, do not reserve any space for it
  * Enhancements:
    + rrdcached: add hosts_access support
    + rrdfetch/graph: introduce "epoch" as a new base time reference, meaning timestamp 0: you can now write epoch+11111111s or epoch+19711205s
  * update in-tree cgilib to 0.7:
    + allow cookies without regular CGI POST/GET variables
    + support for ';' as delimiter
    + support for multipart/form-data
    + support for file upload
    + decode variable names and data
* Tue Dec  7 2010 coolo@novell.com
- fix perl file list on factory
* Tue Jul 27 2010 anicka@suse.cz
- update to 1.4.4
  * legal: Relicense the RRDCacheD client interface under the MIT
  license
  * legal: Updted FLOSS Exception for latest PHP license
  * rrd_cached: better help output
  * bugfixes
- remove last patch, fixed in upstream
- disable calling autoreconf (needs too new gettext)
* Fri Apr 16 2010 anicka@suse.cz
- fixed bnc#594981 (-double.diff)
* Tue Mar 30 2010 anicka@suse.cz
- update to 1.4.3
  * rrdcached: Log to stderr (in addition to syslog) when running
  in foreground.
  * rrdcached: Added -m command line option.
  * rrdcached: Added -s option so set group permissions of the
  UNIX domain socket.
  * rrd_create: added --no-overwrite option. It prevents rrdtool
  from clobbering existing rrd files.
  * ruby bindings: rb_rrd_xport function
  * use locale settings and _NL_TIME_WEEK_1STDAY to determine
  the first day of the week. Works on Linux at least
  * rrd_graph: \u to backup one line for special legend placement
  tricks
  * rrd_update: new (better) checker for incoming COUNTER
  or DERIVED data.
* Mon Mar  8 2010 coolo@novell.com
- update to 1.4.2
  * RRD Caching Daemon (rrdcached)
  See rrdcached documentation.
  * The output of rrdtool dump has been adjusted to be simpler to parse by
  existing xml parsers.
  * RRD Graphing functions (rrdtool graph)
  + VDEF PERCENTNAN (a PRECENT that ignores NAN)
  + CDEF PREDICT and PREDICTSIGMA functions for on-the-fly
    data prediction without the need to modify existing rrd files as it is
    required for HoltWinters.
  + LibDBI integration provides a path to read data directly of a supported
    SQL database into rrdtool graph. See rrdgraph_libdbi documentation.
  * quite some more - see NEWS and CHANGES
* Mon Apr 20 2009 crrodriguez@suse.de
- use --disable-static instead of removing static libraries
* Mon Apr 20 2009 anicka@suse.cz
- update to 1.3.7
  * many small updates to the POD documents.
  * improved win32 source
  * OSX compilation fixes
  * rrd_fetch: fix memory leak
  * rrd_cgi: fix segfault in error reporting routine
  * rrd_graph: fix TICK for negative numbers
  * rrd_graph: fix image size reporting for LP64BE architectures
  * rrd_resize: fix GROW for mmap (it was totally broken)
* Wed Feb  4 2009 mfabian@suse.de
- bnc#467362: use --with-rrd-default-font="monospace" instead of
  - -with-rrd-default-font=/usr/share/fonts/truetype/DejaVuSansMono.ttf,
  rrdtools uses fontconfig now, not only freetype and the latter
  is not a correct font name for fontconfig.
* Fri Jan 23 2009 anicka@suse.cz
- update to 1.3.6
  * bugfixes, documentation improvements
* Mon Oct  6 2008 anicka@suse.cz
- update to 1.3.4
  * detect short/truncated files on open (rrdtool used to crash
  later on some platforms)
  * stop rrd_resize from altering the original file (mmap side
  effect)
  * fix VDEF and SHIFT use. Now it returns correct data and does
  not crash anymore.
  * fix rrd_xport when used on datasources with different
  resolutions. This has been broken from day 1 of this tools
  exsitance.
  * fixed default prefix for ruby install
  * added rpath for perl bindings on bsd
  * do not [fm]advise past the end of the file since this
  causes crashes on sparc.
* Wed Sep 10 2008 anicka@suse.cz
- update to 1.3.2
  * fix for data corruption bug:
  http://oss.oetiker.ch/rrdtool-trac/ticket/178
* Mon Jul 28 2008 coolo@suse.de
- remove la files and static libs (to fix depending packages)
* Mon Jun 30 2008 schwab@suse.de
- Fix configure script and use of libtool.
* Fri Jun 27 2008 anicka@suse.cz
- update to 1.3.0
  * Multiplicative Holt-Winters Forecasting
  * MMAP IO
  * Graphing with Cairo/Pango
  * New graphv Interface
  * many more changes - major release
* Mon Mar 10 2008 anicka@suse.cz
- update to 1.2.27
  * bindings/ruby/main.c: be more helpful when raising rb_eTypeError
  in string_arr string_arr_new(VALUE rb_strings).
  * src/rrd_update.c: dropping cache after update does not help (in
  this implementation)
  * bindings/Makefile.am, bindings/python/setup.py: yet another
  attempt to make the python build environment REALY cool
  * bindings/Makefile.am, bindings/python/setup.py: make sure the
  python extension gets the final resting place of the rrdlibrary
  compiled in ...
  * src/rrd_graph.c: don't use round since it is c99 ... use
  floor(x+0.5) for positive numbers instead.
  * src/rrd_graph.c: added some more rounding for int to float
  comparisons
  * src/rrd_graph.c: Testing an double and an integer for equality is
  bound to produce odd results on times. Don't do it! --
  * bugfixes, documentation fixes
- remove python patch (fixed in upstream)
* Wed Feb 20 2008 dmueller@suse.de
- make dejavu font requirement unversioned again, as
  there was no released openSUSE distro with the wrongly
  named font
* Mon Jan 14 2008 dmueller@suse.de
- dejavu font was renamed back, adjust
* Wed Nov 28 2007 dmueller@suse.de
- fix default font after dejavu font update
- add dejavu to the package requires
- build parallel
* Mon Jul  9 2007 dmueller@suse.de
- apply python requires only to python-rrdtool subpackage
* Thu Jun 21 2007 dmueller@suse.de
- split off python and -devel package to reduce
  size and make the python dependency optional
  (needed for 1 CD installer)
* Thu May 24 2007 ro@suse.de
- added ldconfig to post scripts
* Wed May  9 2007 anicka@suse.cz
- fix rpath in python module
* Fri May  4 2007 anicka@suse.cz
- update to 2.1.23
  * many bugfixes (mostly python)
- remove stderr.diff and buffer.diff (fixed in upstream)
* Mon Jan 29 2007 anicka@suse.cz
- update to 1.2.18
  * many bugfixes
  * DoS in rrd_graph.c fixed [#231212]
- fix overflow in rrd_tool.c
* Fri Jan  5 2007 anicka@suse.cz
- fix librrd_th.la
- remove packaged fonts and use system fonts instead
- fix last patch
* Tue Jan  2 2007 anicka@suse.cz
- fix memory allocation bug when graphing logarithmic data
  with upstream patch [#231212]
* Mon Sep 25 2006 anicka@suse.cz
- use %%py_requires [#207920]
* Fri Sep 15 2006 anicka@suse.cz
- store value returned with PyTuple_Size in
  Py_ssize_t instead of int
* Mon Jul 17 2006 anicka@suse.cz
- update to 1.2.15
  * vnames can be up to MAX_VNAME_LEN long
  * bugfixes, documentation fixes
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jan  5 2006 anicka@suse.cz
- update to 1.2.12
* Wed Dec 14 2005 max@suse.de
- Fixed installation of the Tcl bindings.
* Tue Nov  1 2005 anicka@suse.cz
- fix build - return proper value from strerror_r
* Wed Sep 21 2005 anicka@suse.cz
- fix build
* Sun Jul 31 2005 cthiel@suse.de
- moved pkgIndex.tcl to /usr/share/tcl/tclrrd
* Tue Jul 26 2005 cthiel@suse.de
- update to 1.2.11
* Tue Jun 21 2005 anicka@suse.cz
- update to 1.2.10
- drop no longer neccessary rrdtool-tcl.patch
* Thu May 19 2005 mcihar@suse.cz
- update to 1.2.8
- reneabled tcl (copilation fixed by rrdtool-tcl.patch)
- added python bindings
* Tue May 10 2005 mcihar@suse.cz
- update to 1.2.6
- dropped tcl for now, it's somewhat broken
* Mon Apr 18 2005 mcihar@suse.de
- include correct config.h
* Wed Aug 11 2004 tcrhak@suse.cz
- update to 1.0.49
* Fri Aug  6 2004 tcrhak@suse.cz
- update to 1.0.48
* Thu Mar  4 2004 tcrhak@suse.cz
- do not use its own (and old) libpng and libz
* Wed Feb 18 2004 tcrhak@suse.cz
- update to version 1.0.46
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Wed Aug 20 2003 mjancar@suse.cz
- require the perl version we build with
* Mon Jul 28 2003 tcrhak@suse.cz
- removed %%{vendor_perl}/auto from filelist
* Mon Jul 28 2003 tcrhak@suse.cz
- update to version 1.0.45
- fixed file list
- require perl
* Mon Jul 28 2003 ro@suse.de
- install perl files to vendor location
* Fri May 23 2003 ro@suse.de
- fix build with current libtool
* Sun Jan 12 2003 tcrhak@suse.cz
- update to 1.0.40
* Tue Nov 19 2002 ro@suse.de
- run full autoreconf and extend configure.in for that
* Fri Aug  9 2002 mls@suse.de
- use sitearch macro
* Tue Jul  9 2002 tcrhak@suse.cz
- update to version 1.0.39
* Mon Jun  3 2002 ro@suse.de
- fix build on lib64 platforms
* Mon May  6 2002 tcrhak@suse.cz
- omitted prefix i386-suse-linux from names of binaries
  and example scripts (bug #16105)
* Fri Feb  8 2002 draht@suse.de
- added rrdtool-1.0.33-zlib-zfree.dif against duplicate free() in
  zlib
* Thu Jun 14 2001 adostal@suse.cz
- fix for new autoconf (add libtoolize --force)
* Wed Apr 11 2001 cihlar@suse.cz
- updated to version 1.0.33
* Mon Mar 19 2001 cihlar@suse.cz
- fixed call of suse_update_config
* Fri Jan 26 2001 cihlar@suse.cz
- package created
